@@ -79,6 +79,9 @@ ControlView::ControlView( QWidget *parent )
     // TODO: Creating a second MapThemeManager may not be the best solution here.
     // MarbleModel also holds one with a QFileSystemWatcher.
     m_mapThemeManager = new MapThemeManager;
+    
+    connect( m_control, SIGNAL( showMapWizard() ), this, SIGNAL( showMapWizard() ) );
+    connect( m_control, SIGNAL( showUploadDialog() ), this, SIGNAL( showUploadDialog() ) );
 }
 
 ControlView::~ControlView()
@@ -88,7 +91,7 @@ ControlView::~ControlView()
 
 QString ControlView::applicationVersion()
 {
-    return "1.0.1 (Stable Release)";
+    return "1.1.0 (stable version)";
 }
 
 void ControlView::zoomIn()
